package com.xinelu.manage.mapper.tasktypedict;

import com.xinelu.manage.domain.tasktypedict.TaskTypeDict;
import com.xinelu.manage.vo.tasktypedict.TaskTypeDictVO;

import java.util.List;


/**
 * 任务类型字典Mapper接口
 *
 * @author xinelu
 * @date 2024-03-11
 */
public interface TaskTypeDictMapper {
    /**
     * 查询任务类型字典
     *
     * @param id 任务类型字典主键
     * @return 任务类型字典
     */
    public TaskTypeDict selectTaskTypeDictById(Long id);

    /**
     * 查询任务类型字典列表
     *
     * @param taskTypeDict 任务类型字典
     * @return 任务类型字典集合
     */
    public List<TaskTypeDict> selectTaskTypeDictList(TaskTypeDict taskTypeDict);

    /**
     * 新增任务类型字典
     *
     * @param taskTypeDict 任务类型字典
     * @return 结果
     */
    public int insertTaskTypeDict(TaskTypeDict taskTypeDict);

    /**
     * 修改任务类型字典
     *
     * @param taskTypeDict 任务类型字典
     * @return 结果
     */
    public int updateTaskTypeDict(TaskTypeDict taskTypeDict);

    /**
     * 删除任务类型字典
     *
     * @param id 任务类型字典主键
     * @return 结果
     */
    public int deleteTaskTypeDictById(Long id);

    /**
     * 批量删除任务类型字典
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTaskTypeDictByIds(Long[] ids);

    /**
     * 查询任务类型字典列表
     *
     * @return 任务类型字典集合
     */
     List<TaskTypeDictVO> selectTaskTypeDicts();
}
